@@ -165,3 +165,10 @@ def find_the_violence_type(string):
     elif string.endswith('_os'): output = 'one-sided violence'
     else: output = 'please check the variable name'
     return output
+
+def give_me_violence_string_label_only(string):
+    if string.endswith('_sb'): output = '_sb'
+    elif string.endswith('_ns'): output = '_ns'
+    elif string.endswith('_os'): output = '_os'
+    else: output = 'please check the variable name'
+    return output
